@@ -4,10 +4,10 @@
 #
 # Copyright (C) 2007 Oliver Charles
 # Copyright (C) 2007, 2010-2011 Lukáš Lalinský
-# Copyright (C) 2007-2011, 2014, 2018-2022 Philipp Wolfer
+# Copyright (C) 2007-2011, 2014, 2018-2024 Philipp Wolfer
 # Copyright (C) 2011 Michael Wiencek
 # Copyright (C) 2011-2012, 2015 Wieland Hoffmann
-# Copyright (C) 2013-2015, 2018-2021 Laurent Monin
+# Copyright (C) 2013-2015, 2018-2022 Laurent Monin
 # Copyright (C) 2016 Ville Skyttä
 # Copyright (C) 2016-2018 Sambhav Kothari
 # Copyright (C) 2017 Antonio Larrosa
@@ -28,7 +28,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 
-from hashlib import md5
+from hashlib import blake2b
 import os
 import shutil
 import tempfile
@@ -37,13 +37,15 @@ from PyQt5.QtCore import (
     QMutex,
     QObject,
     QUrl,
-    QUrlQuery,
 )
 
 from picard import log
 from picard.config import get_config
 from picard.const import DEFAULT_COVER_IMAGE_FILENAME
-from picard.const.sys import IS_WIN
+from picard.const.sys import (
+    IS_MACOS,
+    IS_WIN,
+)
 from picard.coverart.utils import (
     Id3ImageType,
     image_type_as_id3_num,
@@ -58,6 +60,10 @@ from picard.util import (
     periodictouch,
     sanitize_filename,
 )
+from picard.util.filenaming import (
+    make_save_path,
+    make_short_filename,
+)
 from picard.util.scripttofilename import script_to_filename
 
 
@@ -71,17 +77,15 @@ class DataHash:
         self._filename = None
         _datafile_mutex.lock()
         try:
-            m = md5()  # nosec
-            m.update(data)
-            self._hash = m.hexdigest()
+            self._hash = blake2b(data).hexdigest()
             if self._hash not in _datafiles:
                 (fd, self._filename) = tempfile.mkstemp(prefix=prefix, suffix=suffix)
                 QObject.tagger.register_cleanup(self.delete_file)
-                with os.fdopen(fd, "wb") as imagefile:
+                with os.fdopen(fd, 'wb') as imagefile:
                     imagefile.write(data)
                 _datafiles[self._hash] = self._filename
                 periodictouch.register_file(self._filename)
-                log.debug("Saving image data %s to %r" % (self._hash, self._filename))
+                log.debug("Saving image data %s to %r", self._hash, self._filename)
             else:
                 self._filename = _datafiles[self._hash]
         finally:
@@ -112,7 +116,7 @@ class DataHash:
     @property
     def data(self):
         if self._filename:
-            with open(self._filename, "rb") as imagefile:
+            with open(self._filename, 'rb') as imagefile:
                 return imagefile.read()
         return None
 
@@ -144,7 +148,7 @@ class CoverArtImage:
     # `is_front` has to be explicitly set, it is used to handle CAA is_front
     # indicator
     is_front = None
-    sourceprefix = "URL"
+    sourceprefix = 'URL'
 
     def __init__(self, url=None, types=None, comment='', data=None, support_types=None,
                  support_multi_types=None, id3_type=None):
@@ -153,7 +157,10 @@ class CoverArtImage:
         else:
             self.types = types
         if url is not None:
-            self.parse_url(url)
+            if not isinstance(url, QUrl):
+                self.url = QUrl(url)
+            else:
+                self.url = url
         else:
             self.url = None
         self.comment = comment
@@ -163,24 +170,17 @@ class CoverArtImage:
         self.can_be_saved_to_tags = True
         self.can_be_saved_to_disk = True
         self.can_be_saved_to_metadata = True
-        self.id3_type = id3_type
         if support_types is not None:
             self.support_types = support_types
         if support_multi_types is not None:
             self.support_multi_types = support_multi_types
         if data is not None:
             self.set_data(data)
-
-    def parse_url(self, url):
-        self.url = QUrl(url)
-        self.host = self.url.host()
-        self.port = self.url.port(443 if self.url.scheme() == 'https' else 80)
-        self.path = self.url.path(QUrl.ComponentFormattingOption.FullyEncoded)
-        if self.url.hasQuery():
-            query = QUrlQuery(self.url.query())
-            self.queryargs = dict(query.queryItems())
-        else:
-            self.queryargs = None
+        try:
+            self.id3_type = id3_type
+        except ValueError:
+            log.warning("Invalid ID3 image type %r in %r", type, self)
+            self.id3_type = Id3ImageType.OTHER
 
     @property
     def source(self):
@@ -216,29 +216,35 @@ class CoverArtImage:
                                                                 self.datalength,
                                                                 self.tempfile_filename)
 
-    def __repr__(self):
-        p = []
+    def _repr(self):
         if self.url is not None:
-            p.append("url=%r" % self.url.toString())
+            yield "url=%r" % self.url.toString()
         if self.types:
-            p.append("types=%r" % self.types)
-        p.append('support_types=%r' % self.support_types)
-        p.append('support_multi_types=%r' % self.support_types)
+            yield "types=%r" % self.types
+        yield 'support_types=%r' % self.support_types
+        yield 'support_multi_types=%r' % self.support_multi_types
         if self.is_front is not None:
-            p.append("is_front=%r" % self.is_front)
+            yield "is_front=%r" % self.is_front
         if self.comment:
-            p.append("comment=%r" % self.comment)
-        return "%s(%s)" % (self.__class__.__name__, ", ".join(p))
+            yield "comment=%r" % self.comment
+
+    def __repr__(self):
+        return "%s(%s)" % (self.__class__.__name__, ", ".join(self._repr()))
+
+    def _str(self):
+        if self.url is not None:
+            yield "from %s" % self.url.toString()
+        if self.types:
+            yield "of type %s" % ','.join(self.types)
+        if self.comment:
+            yield "and comment '%s'" % self.comment
 
     def __str__(self):
-        p = ['Image']
-        if self.url is not None:
-            p.append("from %s" % self.url.toString())
-        if self.types:
-            p.append("of type %s" % ','.join(self.types))
-        if self.comment:
-            p.append("and comment '%s'" % self.comment)
-        return ' '.join(p)
+        output = self.__class__.__name__
+        s = tuple(self._str())
+        if s:
+            output += ' ' + ' '.join(s)
+        return output
 
     def __eq__(self, other):
         if self and other:
@@ -305,20 +311,30 @@ class CoverArtImage:
             type = Id3ImageType(type)
         self._id3_type = type
 
-    def _make_image_filename(self, filename, dirname, _metadata):
+    def _make_image_filename(self, filename, dirname, _metadata, win_compat, win_shorten_path):
         metadata = Metadata()
         metadata.copy(_metadata)
-        metadata["coverart_maintype"] = self.maintype
-        metadata["coverart_comment"] = self.comment
+        metadata['coverart_maintype'] = self.maintype
+        metadata['coverart_comment'] = self.comment
         if self.is_front:
-            metadata.add_unique("coverart_types", "front")
+            metadata.add_unique('coverart_types', 'front')
         for cover_type in self.types:
-            metadata.add_unique("coverart_types", cover_type)
+            metadata.add_unique('coverart_types', cover_type)
         filename = script_to_filename(filename, metadata)
         if not filename:
             filename = DEFAULT_COVER_IMAGE_FILENAME
+        dirname = os.path.normpath(dirname)
         if not is_absolute_path(filename):
-            filename = os.path.join(dirname, filename)
+            filename = os.path.normpath(os.path.join(dirname, filename))
+        try:
+            basedir = os.path.commonpath((dirname, os.path.dirname(filename)))
+            relpath = os.path.relpath(filename, start=basedir)
+        except ValueError:
+            basedir = os.path.dirname(filename)
+            relpath = os.path.basename(filename)
+        relpath = make_short_filename(basedir, relpath, win_shorten_path=win_shorten_path)
+        filename = os.path.join(basedir, relpath)
+        filename = make_save_path(filename, win_compat=win_compat, mac_compat=IS_MACOS)
         return encode_filename(filename)
 
     def save(self, dirname, metadata, counters):
@@ -332,17 +348,19 @@ class CoverArtImage:
         if not self.can_be_saved_to_disk:
             return
         config = get_config()
-        if config.setting["image_type_as_filename"] and not self.is_front_image():
-            win_compat = IS_WIN or config.setting["windows_compatibility"]
+        win_compat = IS_WIN or config.setting['windows_compatibility']
+        win_shorten_path = win_compat and not config.setting['windows_long_paths']
+        if config.setting['image_type_as_filename'] and not self.is_front_image():
             filename = sanitize_filename(self.maintype, win_compat=win_compat)
             log.debug("Make cover filename from types: %r -> %r",
                       self.types, filename)
         else:
-            filename = config.setting["cover_image_filename"]
+            filename = config.setting['cover_image_filename']
             log.debug("Using default cover image filename %r", filename)
-        filename = self._make_image_filename(filename, dirname, metadata)
+        filename = self._make_image_filename(
+            filename, dirname, metadata, win_compat, win_shorten_path)
 
-        overwrite = config.setting["save_images_overwrite"]
+        overwrite = config.setting['save_images_overwrite']
         ext = encode_filename(self.extension)
         image_filename = self._next_filename(filename, counters)
         while os.path.exists(image_filename + ext) and not overwrite:
@@ -416,7 +434,7 @@ class CaaCoverArtImage(CoverArtImage):
 
     support_types = True
     support_multi_types = True
-    sourceprefix = "CAA"
+    sourceprefix = 'CAA'
 
     def __init__(self, url, types=None, is_front=False, comment='', data=None):
         super().__init__(url=url, types=types, comment=comment, data=data)
@@ -443,9 +461,9 @@ class TagCoverArtImage(CoverArtImage):
     def __init__(self, file, tag=None, types=None, is_front=None,
                  support_types=False, comment='', data=None,
                  support_multi_types=False, id3_type=None):
-        super().__init__(url=None, types=types, comment=comment, data=data, id3_type=id3_type)
         self.sourcefile = file
         self.tag = tag
+        super().__init__(url=None, types=types, comment=comment, data=data, id3_type=id3_type)
         self.support_types = support_types
         self.support_multi_types = support_multi_types
         if is_front is not None:
@@ -458,19 +476,15 @@ class TagCoverArtImage(CoverArtImage):
         else:
             return 'File %s' % (self.sourcefile)
 
-    def __repr__(self):
-        p = []
-        p.append('%r' % self.sourcefile)
+    def _repr(self):
+        yield '%r' % self.sourcefile
         if self.tag is not None:
-            p.append("tag=%r" % self.tag)
-        if self.types:
-            p.append("types=%r" % self.types)
-        if self.is_front is not None:
-            p.append("is_front=%r" % self.is_front)
-        p.append('support_types=%r' % self.support_types)
-        if self.comment:
-            p.append("comment=%r" % self.comment)
-        return "%s(%s)" % (self.__class__.__name__, ", ".join(p))
+            yield 'tag=%r' % self.tag
+        yield from super()._repr()
+
+    def _str(self):
+        yield 'from %r' % self.sourcefile
+        yield from super()._str()
 
 
 class LocalFileCoverArtImage(CoverArtImage):
