@@ -3,14 +3,16 @@
 # Picard, the next-generation MusicBrainz tagger
 #
 # Copyright (C) 2007-2008, 2011 Lukáš Lalinský
-# Copyright (C) 2008-2009, 2018-2020 Philipp Wolfer
+# Copyright (C) 2008-2009, 2018-2021, 2023 Philipp Wolfer
 # Copyright (C) 2011 Johannes Weißl
 # Copyright (C) 2011-2013 Michael Wiencek
 # Copyright (C) 2012 Chad Wilson
 # Copyright (C) 2013 Calvin Walton
-# Copyright (C) 2013-2014, 2019 Laurent Monin
+# Copyright (C) 2013-2014, 2019-2021 Laurent Monin
 # Copyright (C) 2013-2015, 2017 Sophist-UK
 # Copyright (C) 2019 Zenara Daley
+# Copyright (C) 2023 Bob Swift
+# Copyright (C) 2023 certuna
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -52,7 +54,7 @@ TAG_NAMES = {
     'conductor': N_('Conductor'),
     'copyright': N_('Copyright'),
     'date': N_('Date'),
-    'director': N_('Video Director'),
+    'director': N_('Director'),
     'discid': N_('Disc Id'),
     'discnumber': N_('Disc Number'),
     'discsubtitle': N_('Disc Subtitle'),
@@ -60,6 +62,7 @@ TAG_NAMES = {
     'encodedby': N_('Encoded By'),
     'encodersettings': N_('Encoder Settings'),
     'engineer': N_('Engineer'),
+    'gapless': N_('Gapless Playback'),
     'genre': N_('Genre'),
     'grouping': N_('Grouping'),
     'isrc': N_('ISRC'),
@@ -94,11 +97,14 @@ TAG_NAMES = {
     'originalfilename': N_('Original Filename'),
     'originalyear': N_('Original Year'),
     'performer': N_('Performer'),
+    'podcast': N_('Podcast'),
+    'podcasturl': N_('Podcast URL'),
     'producer': N_('Producer'),
     'r128_album_gain': N_('R128 Album Gain'),
     'r128_track_gain': N_('R128 Track Gain'),
     '~rating': N_('Rating'),
     'releasecountry': N_('Release Country'),
+    'releasedate': N_('Release Date'),
     'releasestatus': N_('Release Status'),
     'releasetype': N_('Release Type'),
     'remixer': N_('Remixer'),
@@ -110,6 +116,8 @@ TAG_NAMES = {
     'replaygain_track_peak': N_('ReplayGain Track Peak'),
     'replaygain_track_range': N_('ReplayGain Track Range'),
     'script': N_('Script'),
+    'show': N_('Show Name'),
+    'showsort': N_('Show Name Sort Order'),
     'showmovement': N_('Show Work & Movement'),
     'subtitle': N_('Subtitle'),
     'title': N_('Title'),
@@ -129,11 +137,30 @@ PRESERVED_TAGS = (
     '~dirname',
     '~extension',
     '~filename',
+    '~file_created_timestamp',
+    '~file_modified_timestamp',
     '~format',
     '~sample_rate',
     '~video',
 )
 
+# Tags that got generated in some way from the audio content.
+# Those can be set by Picard but the new values usually should be kept
+# when moving the file between tags.
+CALCULATED_TAGS = {
+    'acoustid_fingerprint',
+    'acoustid_id',
+    'replaygain_album_gain',
+    'replaygain_album_peak',
+    'replaygain_album_range',
+    'replaygain_reference_loudness',
+    'replaygain_track_gain',
+    'replaygain_track_peak',
+    'replaygain_track_range',
+    'r128_album_gain',
+    'r128_track_gain',
+}
+
 
 def display_tag_name(name):
     if ':' in name:
